@@ -1,7 +1,7 @@
 package App::genpw;
 
-our $DATE = '2018-06-29'; # DATE
-our $VERSION = '0.008'; # VERSION
+our $DATE = '2018-07-01'; # DATE
+our $VERSION = '0.009'; # VERSION
 
 use 5.010001;
 use strict;
@@ -142,7 +142,7 @@ sub _pattern_has_w_conversion {
 
 $SPEC{genpw} = {
     v => 1.1,
-    summary => 'Generate random password (support patterns + wordlists)',
+    summary => 'Generate random password, with patterns and wordlists',
     description => <<'_',
 
 This is yet another utility to generate random password. Features:
@@ -155,7 +155,7 @@ This is yet another utility to generate random password. Features:
 
 Examples:
 
-By default generate base56 password 12-20 characters long (%12$20B):
+By default generate base56 password 12-20 characters long (-p %12$20B):
 
     % genpw
     Uk7Zim6pZeMTZQUyaM
@@ -292,7 +292,7 @@ sub genpw {
 }
 
 1;
-# ABSTRACT: Generate random password (support patterns + wordlists)
+# ABSTRACT: Generate random password, with patterns and wordlists
 
 __END__
 
@@ -302,11 +302,11 @@ __END__
 
 =head1 NAME
 
-App::genpw - Generate random password (support patterns + wordlists)
+App::genpw - Generate random password, with patterns and wordlists
 
 =head1 VERSION
 
-This document describes version 0.008 of App::genpw (from Perl distribution App-genpw), released on 2018-06-29.
+This document describes version 0.009 of App::genpw (from Perl distribution App-genpw), released on 2018-07-01.
 
 =head1 SYNOPSIS
 
@@ -321,7 +321,7 @@ Usage:
 
  genpw(%args) -> [status, msg, result, meta]
 
-Generate random password (support patterns + wordlists).
+Generate random password, with patterns and wordlists.
 
 This is yet another utility to generate random password. Features:
 
@@ -339,7 +339,7 @@ C<rand()>.
 
 Examples:
 
-By default generate base56 password 12-20 characters long (%12$20B):
+By default generate base56 password 12-20 characters long (-p %12$20B):
 
  % genpw
  Uk7Zim6pZeMTZQUyaM
